@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 from django.forms.util import ErrorDict
-from djangular.forms.angular_base import NgFormBaseMixin
+from django.utils.html import format_html
+from djangular.forms.angular_base import NgFormBaseMixin, SafeTuple
 
 
 class NgModelFormMixin(NgFormBaseMixin):
@@ -15,7 +16,7 @@ class NgModelFormMixin(NgFormBaseMixin):
     """
 
     def __init__(self, *args, **kwargs):
-        self.scope_prefix = kwargs.pop('scope_prefix', None)
+        self.scope_prefix = kwargs.pop('scope_prefix', getattr(self, 'scope_prefix', None))
         if hasattr(self, 'Meta') and hasattr(self.Meta, 'ng_models'):
             if not isinstance(self.Meta.ng_models, list):
                 raise TypeError('Meta.ng_model is not of type list')
@@ -44,12 +45,14 @@ class NgModelFormMixin(NgFormBaseMixin):
             for key, fmtstr in directives.items():
                 field.widget.attrs[key] = fmtstr % ng
         super(NgModelFormMixin, self).__init__(*args, **kwargs)
+        if self.scope_prefix == self.form_name:
+            raise ValueError("The form's name may not be identical with its scope_prefix")
 
-    def full_clean(self):
+    def _post_clean(self):
         """
         Rewrite the error dictionary, so that its keys correspond to the model fields.
         """
-        super(NgModelFormMixin, self).full_clean()
+        super(NgModelFormMixin, self)._post_clean()
         if self._errors and self.prefix:
             self._errors = ErrorDict((self.add_prefix(name), value) for name, value in self._errors.items())
 
@@ -64,3 +67,14 @@ class NgModelFormMixin(NgFormBaseMixin):
             if hasattr(field, 'widget') and 'ng-model' in field.widget.attrs:
                 data[name] = self.initial and self.initial.get(name) or field.initial
         return data
+
+    def get_field_errors(self, field):
+        errors = super(NgModelFormMixin, self).get_field_errors(field)
+        identifier = format_html('{0}.{1}', self.form_name, field.name)
+        errors.append(SafeTuple((identifier, '$pristine', '$message', 'invalid', '$message')))
+        return errors
+
+    def non_field_errors(self):
+        errors = super(NgModelFormMixin, self).non_field_errors()
+        errors.append(SafeTuple((self.form_name, '$pristine', '$message', 'invalid', '$message')))
+        return errors
